==> chromium-manager-0.5.3.tgz: package/index.js <==
#!/usr/bin/env node

var https = require("https");
var fs = require("fs");
var unzip = require("unzip");
var exec = require('child_process').exec;
var downloadPath = 'downloads/';
var LastestRevesionURL = 'https://www.googleapis.com/download/storage/v1/b/chromium-browser-snapshots/o/Linux_x64%2FLAST_CHANGE?alt=media';
var sys = require('util')
var exec = require('child_process').exec;

var chromium;

var localRevision = fs.readFileSync ('node_modules/chromium-manager/rev' , 'utf8').toString().trim();


function check4Updates() {  
  https.get(LastestRevesionURL, (res)=>{
    res.setEncoding('utf8');
    res.on('data', (rev)=>{
      if (localRevision === rev.toString().trim())
      {
        console.log('Already have latest version');
      }
      else {
        getChromiun(rev, 'node_modules/chromium-manager/' + downloadPath);
      }
    });
  }
  );
  
}



//console.log(localRevision);


function getChromiun(revesionNumber, path) {
  var received_bytes = 0;
  var totalBites = 0;
  var updateUrl = {
    part1: 'https://www.googleapis.com/download/storage/v1/b/chromium-browser-snapshots/o/Linux_x64%2F',
    part2: '%2Fchrome-linux.zip?alt=media'
  }
  try {
    fs.mkdirSync(path);
  } catch (e) {
    if (e.code != 'EEXIST')
      throw e;
  }
  https.get(updateUrl.part1 + revesionNumber + updateUrl.part2, (res)=>{
    var file = fs.createWriteStream(path + revesionNumber + '.zip' + '.incomplete');
    totalBites = res.headers['content-length'];
    res.on('data', (chunk)=>{
      received_bytes += chunk.length;
      process.stdout.write((' Progress:    ' + (100 * received_bytes / totalBites).toFixed(0) + '% ') + '|  file size: ' + (((parseInt(totalBites, 10)) / 1048576).toFixed(2) + 'Mb' + '\r'));
      file.write(chunk);
    }
    );
    res.on('end', ()=>{
      console.log(' Complete: ');
      fs.renameSync(path + revesionNumber + '.zip' + '.incomplete', path + revesionNumber + '.zip')
      console.log(' Extracting archive...');
      fs.createReadStream(path + revesionNumber + '.zip').pipe(unzip.Extract({
        path: 'node_modules/chromium-manager/chromium'
      })).on('close', function() {
        
        
        //      fs.chmod('chromium/chrome-linux/chrome_sandbox', '755');
        fs.chmod('node_modules/chromium-manager/chromium/chrome-linux/chrome_sandbox', '4755');
        fs.chmod('node_modules/chromium-manager/chromium/chrome-linux/chrome', '4755');
        fs.chmod('node_modules/chromium-manager/chromium/chrome-linux/chrome-wrapper', '4755');
        fs.chmod('node_modules/chromium-manager/chromium/chrome-linux/nacl_helper', '4755'); 
        var file = fs.createWriteStream('node_modules/chromium-manager/' + 'rev');
        file.write(revesionNumber);
      });
      ;
    }
    );
  }
  )
}

function run () {
  exec("node_modules/chromium-manager/chromium/chrome-linux/chrome-wrapper --auto-open-devtools-for-tabs --disable-default-apps --no-first-run --disable-sync --user-data-dir='node_modules/chromium-manager/user-data-dir' ", function (error, stdout, stderr) {
    console.log('stdout: ' + stdout);
    console.log('stderr: ' + stderr);
    if (error !== null) {
      console.log('exec error: ' + error);
    }
  });
}

module.exports = { check4Updates: check4Updates, run: run };

==> chromium-manager-0.5.5.tgz: package/index.js <==
#!/usr/bin/env node

var https = require("https");
var fs = require("fs");
var unzip = require("unzip");
var exec = require('child_process').exec;
var downloadPath = 'downloads/';
var LastestRevesionURL = 'https://www.googleapis.com/download/storage/v1/b/chromium-browser-snapshots/o/Linux_x64%2FLAST_CHANGE?alt=media';
var sys = require('util')
var exec = require('child_process').exec;

var chromium;

var localRevision = fs.readFileSync ('node_modules/chromium-manager/rev' , 'utf8').toString().trim();


function check4Updates() {  
  https.get(LastestRevesionURL, (res)=>{
    res.setEncoding('utf8');
    res.on('data', (rev)=>{
      if (localRevision === rev.toString().trim())
      {
        console.log('Already have latest version');
      }
      else {
        getChromiun(rev, 'node_modules/chromium-manager/' + downloadPath);
      }
    });
  }
  );
  
}



//console.log(localRevision);


function getChromiun(revesionNumber, path) {
  var received_bytes = 0;
  var totalBites = 0;
  var updateUrl = {
    part1: 'https://www.googleapis.com/download/storage/v1/b/chromium-browser-snapshots/o/Linux_x64%2F',
    part2: '%2Fchrome-linux.zip?alt=media'
  }
  try {
    fs.mkdirSync(path);
  } catch (e) {
    if (e.code != 'EEXIST')
      throw e;
  }
  https.get(updateUrl.part1 + revesionNumber + updateUrl.part2, (res)=>{
    var file = fs.createWriteStream(path + revesionNumber + '.zip' + '.incomplete');
    totalBites = res.headers['content-length'];
    res.on('data', (chunk)=>{
      received_bytes += chunk.length;
      process.stdout.write((' Progress:    ' + (100 * received_bytes / totalBites).toFixed(0) + '% ') + '|  file size: ' + (((parseInt(totalBites, 10)) / 1048576).toFixed(2) + 'Mb' + '\r'));
      file.write(chunk);
    }
    );
    res.on('end', ()=>{
      console.log(' Complete: ');
      fs.renameSync(path + revesionNumber + '.zip' + '.incomplete', path + revesionNumber + '.zip')
      console.log(' Extracting archive...');
      fs.createReadStream(path + revesionNumber + '.zip').pipe(unzip.Extract({
        path: 'node_modules/chromium-manager/chromium'
      })).on('close', function() {
        
        
        //      fs.chmod('chromium/chrome-linux/chrome_sandbox', '755');
        fs.chmod('node_modules/chromium-manager/chromium/chrome-linux/chrome_sandbox', '4755');
        fs.chmod('node_modules/chromium-manager/chromium/chrome-linux/chrome', '4755');
        fs.chmod('node_modules/chromium-manager/chromium/chrome-linux/chrome-wrapper', '4755');
        fs.chmod('node_modules/chromium-manager/chromium/chrome-linux/nacl_helper', '4755'); 
        var file = fs.createWriteStream('node_modules/chromium-manager/' + 'rev');
        file.write(revesionNumber);
      });
      ;
    }
    );
  }
  )
}

function run () {
  exec("node_modules/chromium-manager/chromium/chrome-linux/chrome-wrapper --auto-open-devtools-for-tabs --disable-default-apps --no-first-run --disable-sync --user-data-dir='node_modules/chromium-manager/user-data-dir' --disk-cache-dir=/tmp/cache ", function (error, stdout, stderr) {
    console.log('stdout: ' + stdout);
    console.log('stderr: ' + stderr);
    if (error !== null) {
      console.log('exec error: ' + error);
    }
  });
}

module.exports = { check4Updates: check4Updates, run: run };
